@@ -94,4 +94,4 @@ Currently only tested in ubuntu 12.04+""")
     client_app.run()
 
 if __name__ == '__main__':
-    main
+    main()
